==> weblayer-0.0.8-sources.jar: org/tinygroup/weblayer/TinyProcessorManager.java <==
/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.weblayer;

import org.tinygroup.applicationprocessor.configmanager.TinyProcessorConfigManager;



/**
 * tiny servlet 处理器管理接口
 * @author renhui
 *
 */
public interface TinyProcessorManager extends TinyWebResourceManager {

    String TINY_PROCESSOR_MANAGER = "tinyProcessorManager";
	String XSTEAM_PACKAGE_NAME = "weblayer";
	
    /**
     * 根据请求路径,获取servlet处理器进行逻辑处理
     * @param url 请求路径
     * @param context 请求环境对象
     */
	public abstract boolean execute(String url, WebContext context);
	
	
	/**
	 * 设置web资源（servlet或filter）的配置管理接口
	 * @param configManager
	 */
	public abstract void setConfigManager(
			TinyProcessorConfigManager configManager);

}

==> weblayer-0.0.12-sources.jar: org/tinygroup/weblayer/TinyProcessorManager.java <==
/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.weblayer;

import org.tinygroup.weblayer.configmanager.TinyProcessorConfigManager;



/**
 * tiny servlet 处理器管理接口
 * @author renhui
 *
 */
public interface TinyProcessorManager extends TinyWebResourceManager {

    String TINY_PROCESSOR_MANAGER = "tinyProcessorManager";
	String XSTEAM_PACKAGE_NAME = "weblayer";
	
    /**
     * 根据请求路径,获取servlet处理器进行逻辑处理
     * @param url 请求路径
     * @param context 请求环境对象
     */
	public abstract boolean execute(String url, WebContext context);
	
	
	/**
	 * 设置web资源（servlet或filter）的配置管理接口
	 * @param configManager
	 */
	public abstract void setConfigManager(
			TinyProcessorConfigManager configManager);

}
